changeset 10556:3b3668d71811

<moonythedwarf> ` cd nasmbuild/nasm-2.13rc9; ./configure
author HackBot
date Thu, 30 Mar 2017 21:03:42 +0000
parents 532e401e628c
children 23e8673c32c3
files nasmbuild/nasm-2.13rc9/confdefs.h nasmbuild/nasm-2.13rc9/config.log nasmbuild/nasm-2.13rc9/conftest nasmbuild/nasm-2.13rc9/conftest.c
diffstat 3 files changed, 33 insertions(+), 9 deletions(-) [+]
line wrap: on
line diff
--- a/nasmbuild/nasm-2.13rc9/confdefs.h	Thu Mar 30 21:00:23 2017 +0000
+++ b/nasmbuild/nasm-2.13rc9/confdefs.h	Thu Mar 30 21:03:42 2017 +0000
@@ -38,3 +38,7 @@
 #define HAVE_STRNCASECMP 1
 #define HAVE_STRSEP 1
 #define HAVE_STRNLEN 1
+#define HAVE_GETUID 1
+#define HAVE_GETGID 1
+#define HAVE_REALPATH 1
+#define HAVE_CANONICALIZE_FILE_NAME 1
--- a/nasmbuild/nasm-2.13rc9/config.log	Thu Mar 30 21:00:23 2017 +0000
+++ b/nasmbuild/nasm-2.13rc9/config.log	Thu Mar 30 21:03:42 2017 +0000
@@ -989,7 +989,7 @@
 configure:6139: result: yes
 configure:6139: checking for stricmp
 configure:6139: gcc -std=gnu99 -o conftest -g -O3 -fwrapv -U__STRICT_ANSI__ -fno-common   conftest.c  >&5
-/tmp/ccVv6D8q.o: In function `main':
+/tmp/cc4pIDn0.o: In function `main':
 /hackenv/nasmbuild/nasm-2.13rc9/conftest.c:73: undefined reference to `stricmp'
 collect2: error: ld returned 1 exit status
 configure:6139: $? = 1
@@ -1080,7 +1080,7 @@
 configure:6151: result: yes
 configure:6151: checking for strnicmp
 configure:6151: gcc -std=gnu99 -o conftest -g -O3 -fwrapv -U__STRICT_ANSI__ -fno-common   conftest.c  >&5
-/tmp/cc13WttS.o: In function `main':
+/tmp/cc4XWJLk.o: In function `main':
 /hackenv/nasmbuild/nasm-2.13rc9/conftest.c:74: undefined reference to `strnicmp'
 collect2: error: ld returned 1 exit status
 configure:6151: $? = 1
@@ -1173,3 +1173,19 @@
 configure:6173: result: yes
 configure:6185: checking for getuid
 configure:6185: gcc -std=gnu99 -o conftest -g -O3 -fwrapv -U__STRICT_ANSI__ -fno-common   conftest.c  >&5
+configure:6185: $? = 0
+configure:6185: result: yes
+configure:6196: checking for getgid
+configure:6196: gcc -std=gnu99 -o conftest -g -O3 -fwrapv -U__STRICT_ANSI__ -fno-common   conftest.c  >&5
+configure:6196: $? = 0
+configure:6196: result: yes
+configure:6208: checking for realpath
+configure:6208: gcc -std=gnu99 -o conftest -g -O3 -fwrapv -U__STRICT_ANSI__ -fno-common   conftest.c  >&5
+configure:6208: $? = 0
+configure:6208: result: yes
+configure:6219: checking for canonicalize_file_name
+configure:6219: gcc -std=gnu99 -o conftest -g -O3 -fwrapv -U__STRICT_ANSI__ -fno-common   conftest.c  >&5
+configure:6219: $? = 0
+configure:6219: result: yes
+configure:6230: checking for _fullpath
+configure:6230: gcc -std=gnu99 -o conftest -g -O3 -fwrapv -U__STRICT_ANSI__ -fno-common   conftest.c  >&5
--- a/nasmbuild/nasm-2.13rc9/conftest.c	Thu Mar 30 21:00:23 2017 +0000
+++ b/nasmbuild/nasm-2.13rc9/conftest.c	Thu Mar 30 21:03:42 2017 +0000
@@ -38,13 +38,17 @@
 #define HAVE_STRNCASECMP 1
 #define HAVE_STRSEP 1
 #define HAVE_STRNLEN 1
+#define HAVE_GETUID 1
+#define HAVE_GETGID 1
+#define HAVE_REALPATH 1
+#define HAVE_CANONICALIZE_FILE_NAME 1
 /* end confdefs.h.  */
 /* Define getuid to an innocuous variant, in case <limits.h> declares getuid.
    For example, HP-UX 11i <limits.h> declares gettimeofday.  */
-#define getuid innocuous_getuid
+#define _fullpath innocuous__fullpath
 
 /* System header to define __stub macros and hopefully few prototypes,
-    which can conflict with char getuid (); below.
+    which can conflict with char _fullpath (); below.
     Prefer <limits.h> to <assert.h> if __STDC__ is defined, since
     <limits.h> exists even on freestanding compilers.  */
 
@@ -54,7 +58,7 @@
 # include <assert.h>
 #endif
 
-#undef getuid
+#undef _fullpath
 
 /* Override any GCC internal prototype to avoid an error.
    Use char because int might match the return type of a GCC
@@ -62,18 +66,18 @@
 #ifdef __cplusplus
 extern "C"
 #endif
-char getuid ();
+char _fullpath ();
 /* The GNU C library defines this for functions which it implements
     to always fail with ENOSYS.  Some functions are actually named
     something starting with __ and the normal name is an alias.  */
-#if defined __stub_getuid || defined __stub___getuid
+#if defined __stub__fullpath || defined __stub____fullpath
 choke me
 #endif
 
 int
 main ()
 {
-return getuid ();
+return _fullpath ();
   ;
   return 0;
 }
@@ -38,13 +38,17 @@
 /* end confdefs.h.  */
-/* Define getuid to an innocuous variant, in case <limits.h> declares getuid.
+/* Define _fullpath to an innocuous variant, in case <limits.h> declares _fullpath.
    For example, HP-UX 11i <limits.h> declares gettimeofday.  */